You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2017/04/28 09:21:19 UTC

[14/43] isis git commit: ISIS-1603: renames PropertyEditStyle to PromptStyle

ISIS-1603: renames PropertyEditStyle to PromptStyle


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/8a4f6d68
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/8a4f6d68
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/8a4f6d68

Branch: refs/heads/master
Commit: 8a4f6d682e1f1564deed87344dc454e3d41b60e9
Parents: ddd55cd
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Sun Apr 23 15:05:42 2017 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Thu Apr 27 13:26:39 2017 +0100

----------------------------------------------------------------------
 .../applib/layout/component/component.xsd       |  4 +-
 .../guides/rgant/_rgant-PropertyLayout.adoc     | 16 ++--
 .../rgant/_rgant-PropertyLayout_editStyle.adoc  | 25 ------
 .../_rgant-PropertyLayout_promptStyle.adoc      | 25 ++++++
 .../guides/rgcfg/_rgcfg_configuring-core.adoc   |  8 +-
 .../isis/applib/annotation/PromptStyle.java     | 41 +++++++++
 .../applib/annotation/PropertyEditStyle.java    | 45 ----------
 .../isis/applib/annotation/PropertyLayout.java  |  4 +-
 .../layout/component/PropertyLayoutData.java    | 12 +--
 .../promptStyle/PromptStyleConfiguration.java   | 42 +++++++++
 .../object/promptStyle/PromptStyleFacet.java    | 32 +++++++
 .../promptStyle/PromptStyleFacetAbstract.java   | 38 +++++++++
 .../PromptStyleFacetAsConfigured.java           | 37 ++++++++
 .../promptStyle/PromptStyleFacetFallBack.java   | 35 ++++++++
 .../PropertyEditStyleConfiguration.java         | 42 ---------
 .../editStyle/PropertyEditStyleFacet.java       | 32 -------
 .../PropertyEditStyleFacetAbstract.java         | 38 ---------
 .../PropertyEditStyleFacetAsConfigured.java     | 37 --------
 .../PropertyEditStyleFacetFallBack.java         | 35 --------
 ...ptStyleFacetForPropertyLayoutAnnotation.java | 90 ++++++++++++++++++++
 .../PromptStyleFacetForPropertyLayoutXml.java   | 49 +++++++++++
 ...tyleFacetOnPropertyFromLayoutProperties.java | 57 +++++++++++++
 ...itStyleFacetForPropertyLayoutAnnotation.java | 81 ------------------
 .../PropertyEditStyleFacetForPropertyXml.java   | 49 -----------
 ...tyleFacetOnPropertyFromLayoutProperties.java | 57 -------------
 .../PropertyLayoutFacetFactory.java             | 10 +--
 .../layoutmetadata/PropertyLayoutFacetRepr.java |  4 +-
 .../grid/GridSystemServiceAbstract.java         |  4 +-
 .../PromptStyleConfiguration_Test.java          | 74 ++++++++++++++++
 .../PropertyEditStyleConfiguration_Test.java    | 74 ----------------
 ...itStyleFacetFromPropertyAnnotation_Test.java | 68 +++++++--------
 .../wicket/model/models/FormExecutor.java       |  2 +
 .../viewer/wicket/model/models/ScalarModel.java | 14 +--
 .../components/scalars/ScalarPanelAbstract.java | 11 +--
 .../scalars/ScalarPanelTextFieldAbstract.java   |  4 +-
 .../ui/panels/PromptFormPanelAbstract.java      |  3 +-
 36 files changed, 604 insertions(+), 595 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/adocs/documentation/src/main/asciidoc/applib/layout/component/component.xsd
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/applib/layout/component/component.xsd b/adocs/documentation/src/main/asciidoc/applib/layout/component/component.xsd
index e0498ef..cd1d56f 100644
--- a/adocs/documentation/src/main/asciidoc/applib/layout/component/component.xsd
+++ b/adocs/documentation/src/main/asciidoc/applib/layout/component/component.xsd
@@ -60,7 +60,7 @@
       <xs:element minOccurs="0" name="metadataError" type="xs:string"/>
     </xs:sequence>
     <xs:attribute name="cssClass" type="xs:string"/>
-    <xs:attribute name="editStyle" type="tns:propertyEditStyle"/>
+    <xs:attribute name="promptStyle" type="tns:promptStyle"/>
     <xs:attribute name="hidden" type="tns:where"/>
     <xs:attribute name="id" type="xs:string" use="required"/>
     <xs:attribute name="labelPosition" type="tns:labelPosition"/>
@@ -101,7 +101,7 @@
     </xs:restriction>
   </xs:simpleType>
 
-  <xs:simpleType name="propertyEditStyle">
+  <xs:simpleType name="promptStyle">
     <xs:restriction base="xs:string">
       <xs:enumeration value="DIALOG"/>
       <xs:enumeration value="INLINE"/>

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout.adoc
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout.adoc b/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout.adoc
index af66e3d..541694a 100644
--- a/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout.adoc
+++ b/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout.adoc
@@ -29,13 +29,6 @@ The table below summarizes the annotation's attributes.
 |description of this property, eg to be rendered in a tooltip.
 
 
-|xref:../rgant/rgant.adoc#_rgant-PropertyLayout_editStyle[`editStyle()`]
-|`DIALOG`, `INLINE`, `AS_CONFIGURED` +
-(`AS_CONFIGURED`)
-|(`1.15.0-SNAPSHOT`) how a property should be edited within the UI
-
-
-
 |xref:../rgant/rgant.adoc#_rgant-PropertyLayout_hidden[`hidden()`]
 |`EVERYWHERE`, `OBJECT_FORMS`, `PARENTED_TABLES`, `STANDALONE_TABLES`, `ALL_TABLES`, `NOWHERE` +
 (`NOWHERE`)
@@ -72,6 +65,13 @@ A typical use case is if the desired name is a reserved Java keyword, such as `d
 |whether to HTML escape the name of this property.
 
 
+|xref:../rgant/rgant.adoc#_rgant-PropertyLayout_promptStyle[`promptStyle()`]
+|`DIALOG`, `INLINE`, `AS_CONFIGURED` +
+(`AS_CONFIGURED`)
+|(`1.15.0-SNAPSHOT`) how a property prompt should be displayed within the UI
+
+
+
 |xref:../rgant/rgant.adoc#_rgant-PropertyLayout_renderedAsDayBefore[`renderedAsDayBefore()`]
 |`true`, `false` +
 (`false`)
@@ -128,10 +128,10 @@ so that boilerplate-busting tools such as link:https://projectlombok.org/[Projec
 
 include::_rgant-PropertyLayout_cssClass.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_describedAs.adoc[leveloffset=+1]
-include::_rgant-PropertyLayout_editStyle.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_labelPosition.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_multiLine.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_named.adoc[leveloffset=+1]
+include::_rgant-PropertyLayout_promptStyle.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_renderedAsDayBefore.adoc[leveloffset=+1]
 include::_rgant-PropertyLayout_typicalLength.adoc[leveloffset=+1]
 

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_editStyle.adoc
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_editStyle.adoc b/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_editStyle.adoc
deleted file mode 100644
index c5de7a0..0000000
--- a/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_editStyle.adoc
+++ /dev/null
@@ -1,25 +0,0 @@
-[[_rgant-PropertyLayout_editStyle]]
-= `editStyle()` (`1.15.0-SNAPSHOT`)
-:Notice: Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at. http://www.apache.org/licenses/LICENSE-2.0 . Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR  CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
-:_basedir: ../../
-:_imagesdir: images/
-
-
-The `editStyle()` attribute is used to specify whether a domain object property is edited through a dialog box (similar to an action parameter form) or using an inline edit.
-
-If the attribute is not set, then thevalue of the xref:../rgcfg/rgcfg.adoc#_rgcfg_configuring-core[configuration property] `isis.properties.editStyle` is used.
-If this is itself not set, then a dialog box is used.
-
-For example:
-
-[source,java]
-----
-public class Customer {
-    @Property(
-        editStyle=PropertyEditStyle.INLINE
-    )
-    public int getNotes(){ ... }
-    public void setNotes(String notes) { ... }
-}
-----
-

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_promptStyle.adoc
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_promptStyle.adoc b/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_promptStyle.adoc
new file mode 100644
index 0000000..8d780c4
--- /dev/null
+++ b/adocs/documentation/src/main/asciidoc/guides/rgant/_rgant-PropertyLayout_promptStyle.adoc
@@ -0,0 +1,25 @@
+[[_rgant-PropertyLayout_promptStyle]]
+= `promptStyle()` (`1.15.0-SNAPSHOT`)
+:Notice: Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements. See the NOTICE file distributed with this work for additional information regarding copyright ownership. The ASF licenses this file to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at. http://www.apache.org/licenses/LICENSE-2.0 . Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR  CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
+:_basedir: ../../
+:_imagesdir: images/
+
+
+The `promptStyle()` attribute is used to specify whether a domain object property is edited through a dialog box (similar to an action parameter form) or using an inline edit.
+
+If the attribute is not set, then thevalue of the xref:../rgcfg/rgcfg.adoc#_rgcfg_configuring-core[configuration property] `isis.objects.promptStyle` is used.
+If this is itself not set, then a dialog box is used.
+
+For example:
+
+[source,java]
+----
+public class Customer {
+    @Property(
+        promptStyle=PromptStyle.INLINE
+    )
+    public int getNotes(){ ... }
+    public void setNotes(String notes) { ... }
+}
+----
+

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/adocs/documentation/src/main/asciidoc/guides/rgcfg/_rgcfg_configuring-core.adoc
----------------------------------------------------------------------
diff --git a/adocs/documentation/src/main/asciidoc/guides/rgcfg/_rgcfg_configuring-core.adoc b/adocs/documentation/src/main/asciidoc/guides/rgcfg/_rgcfg_configuring-core.adoc
index cd7bc9a..030fad7 100644
--- a/adocs/documentation/src/main/asciidoc/guides/rgcfg/_rgcfg_configuring-core.adoc
+++ b/adocs/documentation/src/main/asciidoc/guides/rgcfg/_rgcfg_configuring-core.adoc
@@ -582,12 +582,12 @@ If enabled, this configuration property will ensure that domain services only de
 |Whether objects' properties and collections can be edited directly (for objects annotated with xref:../rgant/rgant.adoc#_rgant-DomainObject_editing[`@DomainObject#editing()`]); see xref:../rgcfg/rgcfg.adoc#__rgcfg_configuring-core_isis-objects-editing[below] for further discussion.
 
 
-|`isis.properties.` +
-`editStyle`
+|`isis.objects.` +
+`promptStyle`
 |`dialog`,`inline` +
 (`dialog`)
-|(`1.15.0-SNAPSHOT`) whether a domain object property is edited through a dialog box (similar to an action parameter form) or using an inline edit.
-Can be overridden on a property-by-property basis using xref:../rgant/rgant.adoc#_rgant-PropertyLayout_editStyle[`@Property#editStyle()`]).
+|(`1.15.0-SNAPSHOT`) whether the prompt for editing a domain object property is shown in a dialog box or inline within the form.
+Can be overridden on a property-by-property basis using xref:../rgant/rgant.adoc#_rgant-PropertyLayout_promptStyle[`@Property#promptStyle()`]).
 
 
 |`isis.persistor.` +

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/applib/src/main/java/org/apache/isis/applib/annotation/PromptStyle.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/annotation/PromptStyle.java b/core/applib/src/main/java/org/apache/isis/applib/annotation/PromptStyle.java
new file mode 100644
index 0000000..bcfd188
--- /dev/null
+++ b/core/applib/src/main/java/org/apache/isis/applib/annotation/PromptStyle.java
@@ -0,0 +1,41 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+package org.apache.isis.applib.annotation;
+
+/**
+ * How prompting for new values (property edit) should be performed
+ */
+public enum PromptStyle {
+    /**
+     * Edit the property according to the default edit style policy configured in <tt>isis.properties</tt>.
+     *
+     * <p>
+     *      If no editing style is configured, then {@link #DIALOG} is assumed.
+     * </p>
+     */
+    AS_CONFIGURED,
+    /**
+     * Use a dialog for the prompt
+     */
+    DIALOG,
+    /**
+     * Show the form inline, replacing the rendering of the property.
+     */
+    INLINE
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyEditStyle.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyEditStyle.java b/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyEditStyle.java
deleted file mode 100644
index e059cdb..0000000
--- a/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyEditStyle.java
+++ /dev/null
@@ -1,45 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-package org.apache.isis.applib.annotation;
-
-/**
- * How editing of properties should be performed
- */
-public enum PropertyEditStyle {
-    /**
-     * Edit the property according to the default edit style policy configured in <tt>isis.properties</tt>.
-     *
-     * <p>
-     *      If no editing style is configured, then {@link #DIALOG} is assumed.
-     * </p>
-     */
-    AS_CONFIGURED,
-    /**
-     * Edit the property using a dialog (similar to action parameter, but just a single property being changed)
-     */
-    DIALOG,
-    /**
-     * Edit the property inline.
-     *
-     * <p>
-     *     In the Wicket viewer this is implemented using the <code>x-editable</code> library
-     * </p>
-     */
-    INLINE
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyLayout.java
----------------------------------------------------------------------
diff --git a/core/applib/src/main/java/org/apache/isis/applib/layout/component/PropertyLayoutData.java b/core/applib/src/main/java/org/apache/isis/applib/layout/component/PropertyLayoutData.java
index 23b32e2..0485ffd 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/layout/component/PropertyLayoutData.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/layout/component/PropertyLayoutData.java
@@ -30,7 +30,7 @@ import javax.xml.bind.annotation.XmlType;
 import com.google.common.collect.Lists;
 
 import org.apache.isis.applib.annotation.LabelPosition;
-import org.apache.isis.applib.annotation.PropertyEditStyle;
+import org.apache.isis.applib.annotation.PromptStyle;
 import org.apache.isis.applib.annotation.Where;
 
 /**
@@ -107,15 +107,15 @@ public class PropertyLayoutData
     }
 
 
-    private PropertyEditStyle editStyle;
+    private PromptStyle promptStyle;
 
     @XmlAttribute(required = false)
-    public PropertyEditStyle getEditStyle() {
-        return editStyle;
+    public PromptStyle getPromptStyle() {
+        return promptStyle;
     }
 
-    public void setEditStyle(PropertyEditStyle editStyle) {
-        this.editStyle = editStyle;
+    public void setPromptStyle(PromptStyle promptStyle) {
+        this.promptStyle = promptStyle;
     }
 
 

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleConfiguration.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleConfiguration.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleConfiguration.java
new file mode 100644
index 0000000..f833a64
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleConfiguration.java
@@ -0,0 +1,42 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+package org.apache.isis.core.metamodel.facets.object.promptStyle;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.commons.config.IsisConfiguration;
+
+
+public class PromptStyleConfiguration {
+
+    private PromptStyleConfiguration() {}
+
+    public static final String PROMPT_STYLE_KEY = "isis.objects.promptStyle";
+
+    public static PromptStyle parse(final IsisConfiguration configuration) {
+        final String configuredValue = configuration.getString(PROMPT_STYLE_KEY);
+        return PromptStyleConfiguration.parse(configuredValue);
+    }
+
+    private static PromptStyle parse(final String value) {
+        return value != null && value.trim().equalsIgnoreCase(PromptStyle.INLINE.name())
+                ? PromptStyle.INLINE
+                : PromptStyle.DIALOG;
+    }
+
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacet.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacet.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacet.java
new file mode 100644
index 0000000..aef5a4d
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacet.java
@@ -0,0 +1,32 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.object.promptStyle;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.metamodel.facets.SingleValueFacet;
+
+/**
+ * Indicates that the editing of the property should be published.
+ */
+public interface PromptStyleFacet extends SingleValueFacet<PromptStyle> {
+
+    PromptStyle value();
+
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAbstract.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAbstract.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAbstract.java
new file mode 100644
index 0000000..9d1e3b7
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAbstract.java
@@ -0,0 +1,38 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.object.promptStyle;
+
+import org.apache.isis.core.metamodel.facetapi.Facet;
+import org.apache.isis.core.metamodel.facetapi.FacetAbstract;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+
+public abstract class PromptStyleFacetAbstract extends FacetAbstract
+        implements PromptStyleFacet {
+
+
+    public static Class<? extends Facet> type() {
+        return PromptStyleFacet.class;
+    }
+
+    public PromptStyleFacetAbstract(final FacetHolder holder) {
+        super( type(), holder, Derivation.NOT_DERIVED);
+    }
+
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAsConfigured.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAsConfigured.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAsConfigured.java
new file mode 100644
index 0000000..722bc1d
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetAsConfigured.java
@@ -0,0 +1,37 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.object.promptStyle;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+
+public class PromptStyleFacetAsConfigured extends PromptStyleFacetAbstract {
+
+    private final PromptStyle editStyle;
+
+    public PromptStyleFacetAsConfigured(final PromptStyle editStyle, final FacetHolder holder) {
+        super(holder);
+        this.editStyle = editStyle;
+    }
+
+    @Override public PromptStyle value() {
+        return editStyle;
+    }
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetFallBack.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetFallBack.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetFallBack.java
new file mode 100644
index 0000000..29f6074
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/object/promptStyle/PromptStyleFacetFallBack.java
@@ -0,0 +1,35 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.object.promptStyle;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+
+public class PromptStyleFacetFallBack extends PromptStyleFacetAbstract {
+
+    public PromptStyleFacetFallBack(final FacetHolder holder) {
+        super(holder);
+    }
+
+    @Override
+    public PromptStyle value() {
+        return PromptStyle.DIALOG;
+    }
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleConfiguration.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleConfiguration.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleConfiguration.java
deleted file mode 100644
index 921c94f..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleConfiguration.java
+++ /dev/null
@@ -1,42 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-package org.apache.isis.core.metamodel.facets.properties.property.editStyle;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.commons.config.IsisConfiguration;
-
-
-public class PropertyEditStyleConfiguration {
-
-    private PropertyEditStyleConfiguration() {}
-
-    public static final String EDIT_STYLE_KEY = "isis.properties.editStyle";
-
-    public static PropertyEditStyle parse(final IsisConfiguration configuration) {
-        final String configuredValue = configuration.getString(EDIT_STYLE_KEY);
-        return PropertyEditStyleConfiguration.parse(configuredValue);
-    }
-
-    private static PropertyEditStyle parse(final String value) {
-        return value != null && value.trim().equalsIgnoreCase(PropertyEditStyle.INLINE.name())
-                ? PropertyEditStyle.INLINE
-                : PropertyEditStyle.DIALOG;
-    }
-
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacet.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacet.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacet.java
deleted file mode 100644
index 9bdd252..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacet.java
+++ /dev/null
@@ -1,32 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.property.editStyle;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.metamodel.facets.SingleValueFacet;
-
-/**
- * Indicates that the editing of the property should be published.
- */
-public interface PropertyEditStyleFacet extends SingleValueFacet<PropertyEditStyle> {
-
-    PropertyEditStyle value();
-
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAbstract.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAbstract.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAbstract.java
deleted file mode 100644
index 80348c2..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAbstract.java
+++ /dev/null
@@ -1,38 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.property.editStyle;
-
-import org.apache.isis.core.metamodel.facetapi.Facet;
-import org.apache.isis.core.metamodel.facetapi.FacetAbstract;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-
-public abstract class PropertyEditStyleFacetAbstract extends FacetAbstract
-        implements PropertyEditStyleFacet {
-
-
-    public static Class<? extends Facet> type() {
-        return PropertyEditStyleFacet.class;
-    }
-
-    public PropertyEditStyleFacetAbstract(final FacetHolder holder) {
-        super( type(), holder, Derivation.NOT_DERIVED);
-    }
-
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAsConfigured.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAsConfigured.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAsConfigured.java
deleted file mode 100644
index 6f6ff7e..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetAsConfigured.java
+++ /dev/null
@@ -1,37 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.property.editStyle;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-
-public class PropertyEditStyleFacetAsConfigured extends PropertyEditStyleFacetAbstract {
-
-    private final PropertyEditStyle editStyle;
-
-    public PropertyEditStyleFacetAsConfigured(final PropertyEditStyle editStyle, final FacetHolder holder) {
-        super(holder);
-        this.editStyle = editStyle;
-    }
-
-    @Override public PropertyEditStyle value() {
-        return editStyle;
-    }
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetFallBack.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetFallBack.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetFallBack.java
deleted file mode 100644
index b4e0bdb..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/property/editStyle/PropertyEditStyleFacetFallBack.java
+++ /dev/null
@@ -1,35 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.property.editStyle;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-
-public class PropertyEditStyleFacetFallBack extends PropertyEditStyleFacetAbstract {
-
-    public PropertyEditStyleFacetFallBack(final FacetHolder holder) {
-        super(holder);
-    }
-
-    @Override
-    public PropertyEditStyle value() {
-        return PropertyEditStyle.DIALOG;
-    }
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutAnnotation.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutAnnotation.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutAnnotation.java
new file mode 100644
index 0000000..68bbb14
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutAnnotation.java
@@ -0,0 +1,90 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.properties.propertylayout;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.applib.annotation.PropertyLayout;
+import org.apache.isis.core.commons.config.IsisConfiguration;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleConfiguration;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetAbstract;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetAsConfigured;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetFallBack;
+
+public class PromptStyleFacetForPropertyLayoutAnnotation extends PromptStyleFacetAbstract {
+
+    private final PromptStyle promptStyle;
+
+    public PromptStyleFacetForPropertyLayoutAnnotation(final PromptStyle promptStyle, final FacetHolder holder) {
+        super( holder );
+        this.promptStyle = promptStyle;
+    }
+
+    public static PromptStyleFacet create(
+            final PropertyLayout propertyLayout,
+            final IsisConfiguration configuration,
+            final FacetHolder holder) {
+
+        PromptStyle promptStyle = propertyLayout != null? propertyLayout.promptStyle() : null;
+
+        if(promptStyle == null) {
+            if (holder.containsDoOpFacet(PromptStyleFacet.class)) {
+                // do not replace
+                return null;
+            }
+
+            return new PromptStyleFacetFallBack(holder);
+        } else {
+
+            switch (promptStyle) {
+                case DIALOG:
+                case INLINE:
+                    return new PromptStyleFacetForPropertyLayoutAnnotation(promptStyle, holder);
+
+                case AS_CONFIGURED:
+
+                    // do not replace
+                    if (holder.containsDoOpFacet(PromptStyleFacet.class)) {
+                        return null;
+                    }
+
+                    promptStyle = PromptStyleConfiguration.parse(configuration);
+                    return new PromptStyleFacetAsConfigured(promptStyle, holder);
+
+                default:
+
+                    // do not replace
+                    if (holder.containsDoOpFacet(PromptStyleFacet.class)) {
+                        return null;
+                    }
+
+                    promptStyle = PromptStyleConfiguration.parse(configuration);
+                    return new PromptStyleFacetAsConfigured(promptStyle, holder);
+            }
+        }
+
+    }
+
+    @Override
+    public PromptStyle value() {
+        return promptStyle;
+    }
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutXml.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutXml.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutXml.java
new file mode 100644
index 0000000..5df1ffd
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetForPropertyLayoutXml.java
@@ -0,0 +1,49 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.properties.propertylayout;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.applib.layout.component.PropertyLayoutData;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetAbstract;
+
+public class PromptStyleFacetForPropertyLayoutXml extends PromptStyleFacetAbstract {
+
+    public static PromptStyleFacet create(PropertyLayoutData propertyLayout, FacetHolder holder) {
+        if(propertyLayout == null) {
+            return null;
+        }
+        final PromptStyle promptStyle = propertyLayout.getPromptStyle();
+        return promptStyle != null ? new PromptStyleFacetForPropertyLayoutXml(promptStyle, holder) : null;
+    }
+
+    private final PromptStyle promptStyle;
+
+    private PromptStyleFacetForPropertyLayoutXml(PromptStyle promptStyle, FacetHolder holder) {
+        super(holder);
+        this.promptStyle = promptStyle;
+    }
+
+    @Override
+    public PromptStyle value() {
+        return promptStyle;
+    }
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetOnPropertyFromLayoutProperties.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetOnPropertyFromLayoutProperties.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetOnPropertyFromLayoutProperties.java
new file mode 100644
index 0000000..0f11ff4
--- /dev/null
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PromptStyleFacetOnPropertyFromLayoutProperties.java
@@ -0,0 +1,57 @@
+/*
+ *  Licensed to the Apache Software Foundation (ASF) under one
+ *  or more contributor license agreements.  See the NOTICE file
+ *  distributed with this work for additional information
+ *  regarding copyright ownership.  The ASF licenses this file
+ *  to you under the Apache License, Version 2.0 (the
+ *  "License"); you may not use this file except in compliance
+ *  with the License.  You may obtain a copy of the License at
+ *
+ *        http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing,
+ *  software distributed under the License is distributed on an
+ *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ *  KIND, either express or implied.  See the License for the
+ *  specific language governing permissions and limitations
+ *  under the License.
+ */
+
+package org.apache.isis.core.metamodel.facets.properties.propertylayout;
+
+import java.util.Properties;
+
+import com.google.common.base.Strings;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.metamodel.facetapi.FacetHolder;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetAbstract;
+
+public class PromptStyleFacetOnPropertyFromLayoutProperties extends PromptStyleFacetAbstract {
+
+    private final PromptStyle promptStyle;
+
+    public static PromptStyleFacet create(Properties properties, FacetHolder holder) {
+        final PromptStyle promptStyle = promptStyle(properties);
+        return promptStyle != null? new PromptStyleFacetOnPropertyFromLayoutProperties(promptStyle, holder): null;
+    }
+
+    private PromptStyleFacetOnPropertyFromLayoutProperties(PromptStyle promptStyle, FacetHolder holder) {
+        super(holder);
+        this.promptStyle = promptStyle;
+    }
+
+    private static PromptStyle promptStyle(Properties properties) {
+        if(properties == null) {
+            return null;
+        }
+        String propertyEditStyle = Strings.emptyToNull(properties.getProperty("promptStyle"));
+        return PromptStyle.valueOf(propertyEditStyle);
+    }
+
+    @Override
+    public PromptStyle value() {
+        return promptStyle;
+    }
+}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyLayoutAnnotation.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyLayoutAnnotation.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyLayoutAnnotation.java
deleted file mode 100644
index 6ae9ef9..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyLayoutAnnotation.java
+++ /dev/null
@@ -1,81 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.propertylayout;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.applib.annotation.PropertyLayout;
-import org.apache.isis.core.commons.config.IsisConfiguration;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleConfiguration;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetAbstract;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetAsConfigured;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetFallBack;
-
-public class PropertyEditStyleFacetForPropertyLayoutAnnotation extends PropertyEditStyleFacetAbstract {
-
-    private final PropertyEditStyle editStyle;
-
-    public PropertyEditStyleFacetForPropertyLayoutAnnotation(final PropertyEditStyle editStyle, final FacetHolder holder) {
-        super( holder );
-        this.editStyle = editStyle;
-    }
-
-    public static PropertyEditStyleFacet create(
-            final PropertyLayout propertyLayout,
-            final IsisConfiguration configuration,
-            final FacetHolder holder) {
-
-        PropertyEditStyle editStyle = propertyLayout != null? propertyLayout.editStyle() : null;
-
-        if(editStyle == null) {
-                if (holder.containsDoOpFacet(PropertyEditStyleFacet.class)) {
-                    // do not replace
-                    return null;
-                }
-
-                return new PropertyEditStyleFacetFallBack(holder);
-        } else {
-
-            switch (editStyle) {
-                case DIALOG:
-                case INLINE:
-                    return new PropertyEditStyleFacetForPropertyLayoutAnnotation(editStyle, holder);
-
-                case AS_CONFIGURED:
-                default:
-
-                    // do not replace
-                    if (holder.containsDoOpFacet(PropertyEditStyleFacet.class)) {
-                        return null;
-                    }
-
-                    editStyle = PropertyEditStyleConfiguration.parse(configuration);
-                    return new PropertyEditStyleFacetAsConfigured(editStyle, holder);
-            }
-        }
-
-    }
-
-    @Override
-    public PropertyEditStyle value() {
-        return editStyle;
-    }
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyXml.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyXml.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyXml.java
deleted file mode 100644
index c37190c..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetForPropertyXml.java
+++ /dev/null
@@ -1,49 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.propertylayout;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.applib.layout.component.PropertyLayoutData;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetAbstract;
-
-public class PropertyEditStyleFacetForPropertyXml extends PropertyEditStyleFacetAbstract {
-
-    public static PropertyEditStyleFacet create(PropertyLayoutData propertyLayout, FacetHolder holder) {
-        if(propertyLayout == null) {
-            return null;
-        }
-        final PropertyEditStyle propertyEditStyle = propertyLayout.getEditStyle();
-        return propertyEditStyle != null ? new PropertyEditStyleFacetForPropertyXml(propertyEditStyle, holder) : null;
-    }
-
-    private final PropertyEditStyle propertyEditStyle;
-
-    private PropertyEditStyleFacetForPropertyXml(PropertyEditStyle propertyEditStyle, FacetHolder holder) {
-        super(holder);
-        this.propertyEditStyle = propertyEditStyle;
-    }
-
-    @Override
-    public PropertyEditStyle value() {
-        return propertyEditStyle;
-    }
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetOnPropertyFromLayoutProperties.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetOnPropertyFromLayoutProperties.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetOnPropertyFromLayoutProperties.java
deleted file mode 100644
index ca8fe5c..0000000
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyEditStyleFacetOnPropertyFromLayoutProperties.java
+++ /dev/null
@@ -1,57 +0,0 @@
-/*
- *  Licensed to the Apache Software Foundation (ASF) under one
- *  or more contributor license agreements.  See the NOTICE file
- *  distributed with this work for additional information
- *  regarding copyright ownership.  The ASF licenses this file
- *  to you under the Apache License, Version 2.0 (the
- *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy of the License at
- *
- *        http://www.apache.org/licenses/LICENSE-2.0
- *
- *  Unless required by applicable law or agreed to in writing,
- *  software distributed under the License is distributed on an
- *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- *  KIND, either express or implied.  See the License for the
- *  specific language governing permissions and limitations
- *  under the License.
- */
-
-package org.apache.isis.core.metamodel.facets.properties.propertylayout;
-
-import java.util.Properties;
-
-import com.google.common.base.Strings;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetAbstract;
-
-public class PropertyEditStyleFacetOnPropertyFromLayoutProperties extends PropertyEditStyleFacetAbstract {
-
-    private final PropertyEditStyle propertyEditStyle;
-
-    public static PropertyEditStyleFacet create(Properties properties, FacetHolder holder) {
-        final PropertyEditStyle propertyEditStyle = propertyEditStyle(properties);
-        return propertyEditStyle != null? new PropertyEditStyleFacetOnPropertyFromLayoutProperties(propertyEditStyle, holder): null;
-    }
-
-    private PropertyEditStyleFacetOnPropertyFromLayoutProperties(PropertyEditStyle propertyEditStyle, FacetHolder holder) {
-        super(holder);
-        this.propertyEditStyle = propertyEditStyle;
-    }
-
-    private static PropertyEditStyle propertyEditStyle(Properties properties) {
-        if(properties == null) {
-            return null;
-        }
-        String propertyEditStyle = Strings.emptyToNull(properties.getProperty("editStyle"));
-        return PropertyEditStyle.valueOf(propertyEditStyle);
-    }
-
-    @Override
-    public PropertyEditStyle value() {
-        return propertyEditStyle;
-    }
-}

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyLayoutFacetFactory.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyLayoutFacetFactory.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyLayoutFacetFactory.java
index 8439de2..f7365b7 100644
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyLayoutFacetFactory.java
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/facets/properties/propertylayout/PropertyLayoutFacetFactory.java
@@ -38,7 +38,7 @@ import org.apache.isis.core.metamodel.facets.objectvalue.labelat.LabelAtFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.multiline.MultiLineFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.renderedadjusted.RenderedAdjustedFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.typicallen.TypicalLengthFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
 
 public class PropertyLayoutFacetFactory extends FacetFactoryAbstract implements ContributeeMemberFacetFactory {
 
@@ -92,14 +92,14 @@ public class PropertyLayoutFacetFactory extends FacetFactoryAbstract implements
     }
 
     void processEditStyle(final FacetHolder holder, final Properties properties, final PropertyLayout propertyLayout) {
-        PropertyEditStyleFacet propertyEditStyleFacet = PropertyEditStyleFacetOnPropertyFromLayoutProperties
+        PromptStyleFacet promptStyleFacet = PromptStyleFacetOnPropertyFromLayoutProperties
                 .create(properties, holder);
-        if(propertyEditStyleFacet == null) {
-            propertyEditStyleFacet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+        if(promptStyleFacet == null) {
+            promptStyleFacet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(propertyLayout, getConfiguration(), holder);
         }
 
-        FacetUtil.addFacet(propertyEditStyleFacet);
+        FacetUtil.addFacet(promptStyleFacet);
     }
 
     void processHidden(final FacetHolder holder, final Properties properties, final PropertyLayout propertyLayout) {

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/layoutmetadata/PropertyLayoutFacetRepr.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/layoutmetadata/PropertyLayoutFacetRepr.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/layoutmetadata/PropertyLayoutFacetRepr.java
index 2c0d333..e96f744 100644
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/layoutmetadata/PropertyLayoutFacetRepr.java
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/layoutmetadata/PropertyLayoutFacetRepr.java
@@ -18,14 +18,14 @@ package org.apache.isis.core.metamodel.layoutmetadata;
 
 
 import org.apache.isis.applib.annotation.LabelPosition;
-import org.apache.isis.applib.annotation.PropertyEditStyle;
+import org.apache.isis.applib.annotation.PromptStyle;
 import org.apache.isis.applib.annotation.Where;
 
 public class PropertyLayoutFacetRepr {
 
     public String cssClass;
     public String describedAs;
-    public PropertyEditStyle editStyle;
+    public PromptStyle editStyle;
     public Where hidden;
     public LabelPosition labelPosition;
     public int multiLine;

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/main/java/org/apache/isis/core/metamodel/services/grid/GridSystemServiceAbstract.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/services/grid/GridSystemServiceAbstract.java b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/services/grid/GridSystemServiceAbstract.java
index 4056300..2a3db3a 100644
--- a/core/metamodel/src/main/java/org/apache/isis/core/metamodel/services/grid/GridSystemServiceAbstract.java
+++ b/core/metamodel/src/main/java/org/apache/isis/core/metamodel/services/grid/GridSystemServiceAbstract.java
@@ -99,7 +99,7 @@ import org.apache.isis.core.metamodel.facets.properties.propertylayout.HiddenFac
 import org.apache.isis.core.metamodel.facets.properties.propertylayout.LabelAtFacetForPropertyXml;
 import org.apache.isis.core.metamodel.facets.properties.propertylayout.MultiLineFacetForPropertyXml;
 import org.apache.isis.core.metamodel.facets.properties.propertylayout.NamedFacetForPropertyXml;
-import org.apache.isis.core.metamodel.facets.properties.propertylayout.PropertyEditStyleFacetForPropertyXml;
+import org.apache.isis.core.metamodel.facets.properties.propertylayout.PromptStyleFacetForPropertyLayoutXml;
 import org.apache.isis.core.metamodel.facets.properties.propertylayout.RenderedAdjustedFacetForPropertyXml;
 import org.apache.isis.core.metamodel.facets.properties.propertylayout.TypicalLengthFacetForPropertyXml;
 import org.apache.isis.core.metamodel.spec.ObjectSpecification;
@@ -307,7 +307,7 @@ public abstract class GridSystemServiceAbstract<G extends Grid> implements GridS
                 FacetUtil.addOrReplaceFacet(CssClassFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));
                 FacetUtil.addOrReplaceFacet(DescribedAsFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));
                 FacetUtil.addOrReplaceFacet(
-                        PropertyEditStyleFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));
+                        PromptStyleFacetForPropertyLayoutXml.create(propertyLayoutData, oneToOneAssociation));
                 FacetUtil.addOrReplaceFacet(HiddenFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));
                 FacetUtil.addOrReplaceFacet(LabelAtFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));
                 FacetUtil.addOrReplaceFacet(MultiLineFacetForPropertyXml.create(propertyLayoutData, oneToOneAssociation));

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PromptStyleConfiguration_Test.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PromptStyleConfiguration_Test.java b/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PromptStyleConfiguration_Test.java
new file mode 100644
index 0000000..d366697
--- /dev/null
+++ b/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PromptStyleConfiguration_Test.java
@@ -0,0 +1,74 @@
+package org.apache.isis.core.metamodel.facets.properties.editstyle;
+
+import org.jmock.Expectations;
+import org.jmock.auto.Mock;
+import org.junit.Assert;
+import org.junit.Rule;
+import org.junit.Test;
+
+import org.apache.isis.applib.annotation.PromptStyle;
+import org.apache.isis.core.commons.config.IsisConfiguration;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleConfiguration;
+import org.apache.isis.core.unittestsupport.jmocking.JUnitRuleMockery2;
+
+import static org.hamcrest.CoreMatchers.is;
+
+public class PromptStyleConfiguration_Test {
+
+    @Rule
+    public JUnitRuleMockery2 context = JUnitRuleMockery2.createFor(JUnitRuleMockery2.Mode.INTERFACES_AND_CLASSES);
+
+    @Mock
+    IsisConfiguration mockIsisConfiguration;
+
+    @Test
+    public void when_none() throws Exception {
+        context.checking(new Expectations() {{
+            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
+            will(returnValue(null));
+        }});
+        PromptStyle editStyle = PromptStyleConfiguration.parse(mockIsisConfiguration);
+        Assert.assertThat(editStyle, is(PromptStyle.DIALOG));
+    }
+
+    @Test
+    public void when_inline() throws Exception {
+        context.checking(new Expectations() {{
+            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
+            will(returnValue("inline"));
+        }});
+        PromptStyle editStyle = PromptStyleConfiguration.parse(mockIsisConfiguration);
+        Assert.assertThat(editStyle, is(PromptStyle.INLINE));
+    }
+
+    @Test
+    public void when_inline_mixed_case_and_superfluous_characters() throws Exception {
+        context.checking(new Expectations() {{
+            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
+            will(returnValue(" inLIne "));
+        }});
+        PromptStyle editStyle = PromptStyleConfiguration.parse(mockIsisConfiguration);
+        Assert.assertThat(editStyle, is(PromptStyle.INLINE));
+    }
+
+    @Test
+    public void when_dialog() throws Exception {
+        context.checking(new Expectations() {{
+            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
+            will(returnValue("dialog"));
+        }});
+        PromptStyle editStyle = PromptStyleConfiguration.parse(mockIsisConfiguration);
+        Assert.assertThat(editStyle, is(PromptStyle.DIALOG));
+    }
+
+    @Test
+    public void when_invalid() throws Exception {
+        context.checking(new Expectations() {{
+            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
+            will(returnValue("garbage"));
+        }});
+        PromptStyle editStyle = PromptStyleConfiguration.parse(mockIsisConfiguration);
+        Assert.assertThat(editStyle, is(PromptStyle.DIALOG));
+    }
+
+}
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleConfiguration_Test.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleConfiguration_Test.java b/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleConfiguration_Test.java
deleted file mode 100644
index 95a12ce..0000000
--- a/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleConfiguration_Test.java
+++ /dev/null
@@ -1,74 +0,0 @@
-package org.apache.isis.core.metamodel.facets.properties.editstyle;
-
-import org.jmock.Expectations;
-import org.jmock.auto.Mock;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-
-import org.apache.isis.applib.annotation.PropertyEditStyle;
-import org.apache.isis.core.commons.config.IsisConfiguration;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleConfiguration;
-import org.apache.isis.core.unittestsupport.jmocking.JUnitRuleMockery2;
-
-import static org.hamcrest.CoreMatchers.is;
-
-public class PropertyEditStyleConfiguration_Test {
-
-    @Rule
-    public JUnitRuleMockery2 context = JUnitRuleMockery2.createFor(JUnitRuleMockery2.Mode.INTERFACES_AND_CLASSES);
-
-    @Mock
-    IsisConfiguration mockIsisConfiguration;
-
-    @Test
-    public void when_none() throws Exception {
-        context.checking(new Expectations() {{
-            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
-            will(returnValue(null));
-        }});
-        PropertyEditStyle editStyle = PropertyEditStyleConfiguration.parse(mockIsisConfiguration);
-        Assert.assertThat(editStyle, is(PropertyEditStyle.DIALOG));
-    }
-
-    @Test
-    public void when_inline() throws Exception {
-        context.checking(new Expectations() {{
-            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
-            will(returnValue("inline"));
-        }});
-        PropertyEditStyle editStyle = PropertyEditStyleConfiguration.parse(mockIsisConfiguration);
-        Assert.assertThat(editStyle, is(PropertyEditStyle.INLINE));
-    }
-
-    @Test
-    public void when_inline_mixed_case_and_superfluous_characters() throws Exception {
-        context.checking(new Expectations() {{
-            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
-            will(returnValue(" inLIne "));
-        }});
-        PropertyEditStyle editStyle = PropertyEditStyleConfiguration.parse(mockIsisConfiguration);
-        Assert.assertThat(editStyle, is(PropertyEditStyle.INLINE));
-    }
-
-    @Test
-    public void when_dialog() throws Exception {
-        context.checking(new Expectations() {{
-            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
-            will(returnValue("dialog"));
-        }});
-        PropertyEditStyle editStyle = PropertyEditStyleConfiguration.parse(mockIsisConfiguration);
-        Assert.assertThat(editStyle, is(PropertyEditStyle.DIALOG));
-    }
-
-    @Test
-    public void when_invalid() throws Exception {
-        context.checking(new Expectations() {{
-            oneOf(mockIsisConfiguration).getString("isis.properties.editStyle");
-            will(returnValue("garbage"));
-        }});
-        PropertyEditStyle editStyle = PropertyEditStyleConfiguration.parse(mockIsisConfiguration);
-        Assert.assertThat(editStyle, is(PropertyEditStyle.DIALOG));
-    }
-
-}
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleFacetFromPropertyAnnotation_Test.java
----------------------------------------------------------------------
diff --git a/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleFacetFromPropertyAnnotation_Test.java b/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleFacetFromPropertyAnnotation_Test.java
index 854b8a0..b6db5cf 100644
--- a/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleFacetFromPropertyAnnotation_Test.java
+++ b/core/metamodel/src/test/java/org/apache/isis/core/metamodel/facets/properties/editstyle/PropertyEditStyleFacetFromPropertyAnnotation_Test.java
@@ -7,15 +7,15 @@ import org.junit.Assert;
 import org.junit.Rule;
 import org.junit.Test;
 
-import org.apache.isis.applib.annotation.PropertyEditStyle;
+import org.apache.isis.applib.annotation.PromptStyle;
 import org.apache.isis.applib.annotation.PropertyLayout;
 import org.apache.isis.core.commons.config.IsisConfiguration;
 import org.apache.isis.core.commons.matchers.IsisMatchers;
 import org.apache.isis.core.metamodel.facetapi.FacetHolder;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetAsConfigured;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacetFallBack;
-import org.apache.isis.core.metamodel.facets.properties.propertylayout.PropertyEditStyleFacetForPropertyLayoutAnnotation;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetAsConfigured;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacetFallBack;
+import org.apache.isis.core.metamodel.facets.properties.propertylayout.PromptStyleFacetForPropertyLayoutAnnotation;
 import org.apache.isis.core.unittestsupport.jmocking.JUnitRuleMockery2;
 
 import static org.hamcrest.CoreMatchers.is;
@@ -42,72 +42,72 @@ public class PropertyEditStyleFacetFromPropertyAnnotation_Test {
         public void when_annotated_with_dialog() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
-                will(returnValue(PropertyEditStyle.DIALOG));
+                allowing(mockPropertyLayout).promptStyle();
+                will(returnValue(PromptStyle.DIALOG));
 
                 never(mockConfiguration);
             }});
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
-            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PropertyEditStyleFacetForPropertyLayoutAnnotation.class)));
-            Assert.assertThat(facet.value(), is(PropertyEditStyle.DIALOG));
+            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PromptStyleFacetForPropertyLayoutAnnotation.class)));
+            Assert.assertThat(facet.value(), is(PromptStyle.DIALOG));
         }
 
         @Test
         public void when_annotated_with_inline() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
-                will(returnValue(PropertyEditStyle.INLINE));
+                allowing(mockPropertyLayout).promptStyle();
+                will(returnValue(PromptStyle.INLINE));
 
                 never(mockConfiguration);
             }});
 
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
-            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PropertyEditStyleFacetForPropertyLayoutAnnotation.class)));
-            Assert.assertThat(facet.value(), is(PropertyEditStyle.INLINE));
+            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PromptStyleFacetForPropertyLayoutAnnotation.class)));
+            Assert.assertThat(facet.value(), is(PromptStyle.INLINE));
         }
 
         @Test
         public void when_annotated_with_as_configured() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
-                will(returnValue(PropertyEditStyle.AS_CONFIGURED));
+                allowing(mockPropertyLayout).promptStyle();
+                will(returnValue(PromptStyle.AS_CONFIGURED));
 
                 oneOf(mockConfiguration).getString("isis.properties.editStyle");
-                will(returnValue(PropertyEditStyle.INLINE.name()));
+                will(returnValue(PromptStyle.INLINE.name()));
 
-                allowing(mockFacetHolder).containsDoOpFacet(PropertyEditStyleFacet.class);
+                allowing(mockFacetHolder).containsDoOpFacet(PromptStyleFacet.class);
                 will(returnValue(false));
             }});
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
-            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PropertyEditStyleFacetAsConfigured.class)));
-            Assert.assertThat(facet.value(), is(PropertyEditStyle.INLINE));
+            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PromptStyleFacetAsConfigured.class)));
+            Assert.assertThat(facet.value(), is(PromptStyle.INLINE));
         }
 
         @Test
         public void when_annotated_with_as_configured_but_already_has_doop_facet() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
-                will(returnValue(PropertyEditStyle.AS_CONFIGURED));
+                allowing(mockPropertyLayout).promptStyle();
+                will(returnValue(PromptStyle.AS_CONFIGURED));
 
-                oneOf(mockFacetHolder).containsDoOpFacet(PropertyEditStyleFacet.class);
+                oneOf(mockFacetHolder).containsDoOpFacet(PromptStyleFacet.class);
                 will(returnValue(true));
 
                 never(mockConfiguration);
             }});
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
             Assert.assertThat(facet, is(nullValue()));
@@ -117,36 +117,36 @@ public class PropertyEditStyleFacetFromPropertyAnnotation_Test {
         public void when_not_annotated() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
+                allowing(mockPropertyLayout).promptStyle();
                 will(returnValue(null));
 
-                allowing(mockFacetHolder).containsDoOpFacet(PropertyEditStyleFacet.class);
+                allowing(mockFacetHolder).containsDoOpFacet(PromptStyleFacet.class);
                 will(returnValue(false));
 
                 never(mockConfiguration);
             }});
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
-            Assert.assertThat(facet.value(), is(PropertyEditStyle.DIALOG));
-            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PropertyEditStyleFacetFallBack.class)));
+            Assert.assertThat(facet.value(), is(PromptStyle.DIALOG));
+            Assert.assertThat(facet, is((Matcher) IsisMatchers.anInstanceOf(PromptStyleFacetFallBack.class)));
         }
 
         @Test
         public void when_not_annotated_but_already_has_doop_facet() throws Exception {
 
             context.checking(new Expectations() {{
-                allowing(mockPropertyLayout).editStyle();
+                allowing(mockPropertyLayout).promptStyle();
                 will(returnValue(null));
 
-                allowing(mockFacetHolder).containsDoOpFacet(PropertyEditStyleFacet.class);
+                allowing(mockFacetHolder).containsDoOpFacet(PromptStyleFacet.class);
                 will(returnValue(true));
 
                 never(mockConfiguration);
             }});
 
-            PropertyEditStyleFacet facet = PropertyEditStyleFacetForPropertyLayoutAnnotation
+            PromptStyleFacet facet = PromptStyleFacetForPropertyLayoutAnnotation
                     .create(mockPropertyLayout, mockConfiguration, mockFacetHolder);
 
             Assert.assertThat(facet, is(nullValue()));

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/FormExecutor.java
----------------------------------------------------------------------
diff --git a/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/FormExecutor.java b/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/FormExecutor.java
index 43802b7..a04c1d1 100644
--- a/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/FormExecutor.java
+++ b/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/FormExecutor.java
@@ -24,6 +24,8 @@ import java.io.Serializable;
 import org.apache.wicket.ajax.AjaxRequestTarget;
 import org.apache.wicket.markup.html.form.Form;
 
+import org.apache.isis.applib.annotation.PromptStyle;
+
 /**
  * Passed through the {@link ActionModel} or {@link ScalarModel}, allowing
  * two different Wicket UI components (eg owning <code>ActionPanel</code> and

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java
----------------------------------------------------------------------
diff --git a/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java b/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java
index 17c32be..918056f 100644
--- a/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java
+++ b/core/viewer-wicket-model/src/main/java/org/apache/isis/viewer/wicket/model/models/ScalarModel.java
@@ -28,7 +28,7 @@ import java.util.List;
 import com.google.common.collect.FluentIterable;
 import com.google.common.collect.Lists;
 
-import org.apache.isis.applib.annotation.PropertyEditStyle;
+import org.apache.isis.applib.annotation.PromptStyle;
 import org.apache.isis.applib.annotation.Where;
 import org.apache.isis.core.commons.authentication.AuthenticationSession;
 import org.apache.isis.core.commons.authentication.AuthenticationSessionProvider;
@@ -46,7 +46,7 @@ import org.apache.isis.core.metamodel.facets.object.viewmodel.ViewModelFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.fileaccept.FileAcceptFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.mandatory.MandatoryFacet;
 import org.apache.isis.core.metamodel.facets.objectvalue.typicallen.TypicalLengthFacet;
-import org.apache.isis.core.metamodel.facets.properties.property.editStyle.PropertyEditStyleFacet;
+import org.apache.isis.core.metamodel.facets.object.promptStyle.PromptStyleFacet;
 import org.apache.isis.core.metamodel.facets.value.bigdecimal.BigDecimalValueFacet;
 import org.apache.isis.core.metamodel.facets.value.string.StringValueSemanticsProvider;
 import org.apache.isis.core.metamodel.spec.ObjectSpecId;
@@ -919,12 +919,12 @@ public class ScalarModel extends EntityModel implements LinksProvider,HasFormExe
 
 
 
-    public PropertyEditStyle getEditStyle() {
+    public PromptStyle getEditStyle() {
         if (isEditable()) {
-            PropertyEditStyleFacet facet = getFacet(PropertyEditStyleFacet.class);
-            return facet != null && facet.value() == PropertyEditStyle.INLINE
-                    ? PropertyEditStyle.INLINE
-                    : PropertyEditStyle.DIALOG;
+            PromptStyleFacet facet = getFacet(PromptStyleFacet.class);
+            return facet != null && facet.value() == PromptStyle.INLINE
+                    ? PromptStyle.INLINE
+                    : PromptStyle.DIALOG;
         } else {
             // not editable
             return null;
diff --git a/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyLayout.java b/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyLayout.java
index a744219..1594a76 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyLayout.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/annotation/PropertyLayout.java
@@ -43,9 +43,9 @@ public @interface PropertyLayout {
 
 
     /**
      * How the properties of this domain object are be edited, either {@link PropertyEditStyle#DIALOG dialog} or {@link PropertyEditStyle#INLINE inline}.
      */
-    PropertyEditStyle editStyle() default PropertyEditStyle.AS_CONFIGURED;
+    PromptStyle promptStyle() default PromptStyle.AS_CONFIGURED;
 
     /**
      * Indicates where in the UI the property should <i>not</i>not be visible.

http://git-wip-us.apache.org/repos/asf/isis/blob/8a4f6d68/core/applib/src/main/java/org/apache/isis/applib/layout/component/PropertyLayoutData.java
----------------------------------------------------------------------
@@ -43,9 +43,9 @@ public @interface PropertyLayout {
 
     /**
-     * How the properties of this domain object are be edited, either {@link PropertyEditStyle#DIALOG dialog} or {@link PropertyEditStyle#INLINE inline}.
+     * How the properties of this domain object are be edited, either {@link PromptStyle#DIALOG dialog} or {@link PromptStyle#INLINE inline}.
      */